/* icons-nerdfont.h - Icon defintions for CliFM */

/* Taken from
 * https://github.com/jarun/nnn, licensed under BSD-2-Clause.
 * All changes are licensed under GPL-2.0-or-later.
*/

/*
 * This file is part of CliFM
 *
 * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
 * All rights reserved.

 * CliFM is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CliFM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
*/

/* For more codepoints see https://www.nerdfonts.com/cheat-sheet */

#ifndef ICONS_NERDFONT
#define ICONS_NERDFONT

/* Arrows */
#define MD_ARROW_UPWARD    ""
#define MD_ARROW_FORWARD   ""
#define MD_ARROW_DOWNWARD  ""

/* Generics */
#define NERD_DIRECTORY     ""
#define NERD_FILE          ""
#define NERD_EXEC          ""
#define NERD_MANUAL        "󱓷"
#define NERD_LINK          ""

/* Top level and common icons */
#define NERD_ARCHIVE       ""
#define NERD_BINARY        ""
#define NERD_BRIEFCASE     "󱒔"
#define NERD_CHANGELOG     ""
#define NERD_CONFIGURE     ""
#define NERD_DESKTOP       "󰟀"
#define NERD_DOCUMENT      NERD_FILE
#define NERD_DOWNLOADS     "󰇚"
#define NERD_FAV           ""
#define NERD_GAMES         "󱤙"
#define NERD_GIT           "󰊢"
#define NERD_HOME          "󰋜"
#define NERD_LICENSE       "󰈙"
#define NERD_MAKEFILE      ""
#define NERD_MUSIC         "󰋋"
#define NERD_MUSICFILE     "󰝚"
#define NERD_PICTURES      "󰄀"
#define NERD_PICTUREFILE   "󱅬"
#define NERD_PUBLIC        ""
#define NERD_SCRIPT        ""
#define NERD_TEMPLATES     ""
#define NERD_TRASH         ""
#define NERD_VIDEOS        "󰕧"
#define NERD_VIDEOFILE     "󰈰"

#define NERD_ASM           ""
#define NERD_C             ""
#define NERD_CHESS         "󰡘"
#define NERD_CLOJURE       ""
#define NERD_COFFEE        ""
#define NERD_CPLUSPLUS     ""
#define NERD_CSHARP        "󰌛"
#define NERD_CSS3          ""
#define NERD_DART          ""
#define NERD_DATABASE      ""
#define NERD_DIFF          ""
#define NERD_DOCKER        ""
#define NERD_ELECTRON      "󱀤"
#define NERD_ELIXIR        ""
#define NERD_ELM           ""
#define NERD_EMACS         ""
#define NERD_ERLANG        ""
#define NERD_FSHARP        ""
#define NERD_GO            ""
#define NERD_HASKELL       ""
#define NERD_HTML          "󰗀"
#define NERD_JAVA          "󰬷"
#define NERD_JAVASCRIPT    ""
#define NERD_JSON          ""
#define NERD_JULIA         ""
#define NERD_KOTLIN        "󱈙"
#define NERD_LINUX         ""
#define NERD_LUA           ""
#define NERD_MARKDOWN      ""
#define NERD_MYSQL         ""
#define NERD_NIX           ""
#define NERD_OCAML         ""
#define NERD_OPTICALDISK   "󰗮"
#define NERD_PATCH         "󰶯"
#define NERD_PDF           ""
#define NERD_PERL          ""
#define NERD_PHP           "󰌟"
#define NERD_PLAYLIST      "󰲸"
#define NERD_PYTHON        ""
#define NERD_R             "󰟔"
#define NERD_REACT         ""
#define NERD_ROM           ""
#define NERD_RSS           ""
#define NERD_RUBY          ""
#define NERD_RUST          ""
#define NERD_SASS          ""
#define NERD_SCALA         ""
#define NERD_SHARE         ""
#define NERD_SWIFT         "󰛥"
#define NERD_TEX           ""
#define NERD_TS            "󰛦"
#define NERD_TXT           ""
#define NERD_VIM           ""
#define NERD_ZIG           ""
#define NERD_LOCK          ""

#define NERD_EXCELDOC      "󰈜"
#define NERD_PPTDOC        "󰈨"
#define NERD_WORDDOC       "󰈭"
#define NERD_WINDOWS       ""

#define NERD_PHOTOSHOP     ""
#define NERD_HISTORY       "󰋚"
#define NERD_COPYRIGHT     ""
#define NERD_KEY           "󰌆"
#define NERD_FONT          ""
#define NERD_BOOK          ""
#define NERD_CHECKLIST     ""
#define NERD_COMMENTS      ""
#define NERD_VISUALSTUDIO  "󰨞"
#define NERD_DROPBOX       "󰇣"
#define NERD_STEAM         ""

#define NERD_ARCHLINUX     ""
#define NERD_DEBIAN        ""
#define NERD_REDHAT        "󱄛"

#endif /* ICONS_NERDFONT */
